#
# spec file
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name mlt
%define libname lib%{_name}
%define lversion 7.26.0
%define sover 7
%define lib_pkgname %{libname}-%{sover}-%{sover}
%define _name_pp %{_name}++
%define libname_pp lib%{_name_pp}
%define sover_pp 7
%define lversion_pp 7.26.0
%define libpp_pkgname %{libname_pp}-%{sover_pp}-%{sover_pp}
%bcond_without Qt6
%bcond_without rtaudio
Name:           %{libname}
Version:        7.26.0
Release:        1.1
Summary:        Multimedia framework for television broadcasting
License:        GPL-3.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://www.mltframework.org
Source0:        https://github.com/mltframework/mlt/releases/download/v%{version}/mlt-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
%if %{with Qt6} && 0%{?sle_version}
# Qt 6 requires a compiler that fully supports c++-17
BuildRequires:  gcc13-c++
BuildRequires:  gcc13-PIE
%endif
BuildRequires:  ladspa-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  cmake(Qt5Core) >= 5.10
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
%if %{with Qt6}
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6Core5Compat)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Network)
BuildRequires:  cmake(Qt6SvgWidgets)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%else
BuildRequires:  cmake(Qt5Core) >= 5.10
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
%endif
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(frei0r)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(icu-io)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libavcodec) >= 58
BuildRequires:  pkgconfig(libavfilter) >= 7
BuildRequires:  pkgconfig(libavdevice) >= 58
BuildRequires:  pkgconfig(libavformat) >= 58
BuildRequires:  pkgconfig(libavutil) >= 56
BuildRequires:  pkgconfig(libswresample) >= 3
BuildRequires:  pkgconfig(libebur128)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libswscale) >= 5
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(movit)
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(opencv4)
%endif
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(python3)
%if %{with rtaudio}
BuildRequires:  pkgconfig(rtaudio)
%endif
BuildRequires:  pkgconfig(rubberband)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sox)
BuildRequires:  pkgconfig(vidstab)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  pkgconfig(vorbisfile)

%description
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers. The functionality of the system is
provided via an assortment of tools, XML authoring components, and an
plug-in based API.

%package -n %{lib_pkgname}
Summary:        C library API for the MLT multimedia framework
Group:          System/Libraries

%description -n %{lib_pkgname}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the C library API for MLT.

%package -n %{libpp_pkgname}
Summary:        C++ library API for the MLT multimedia framework
Group:          System/Libraries

%description -n %{libpp_pkgname}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the C++ library API for MLT.

%package devel
Summary:        Development files for MLT's C and C++ language API
Group:          Development/Libraries/C and C++
Provides:       libmlt++-devel = %{version}
Requires:       %{lib_pkgname} = %{version}
Requires:       %{libpp_pkgname} = %{version}

%description devel
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

This subpackage contains the headers to make use of the MLT C and
C++ API.

%package -n melt
Summary:        Multimedia framework for television broadcasting
Group:          Productivity/Multimedia/Video/Editors and Convertors
Provides:       melt%{sover} = %{version}
Requires:       %{libname}%{sover}-data = %{version}
Requires:       %{libname}%{sover}-modules = %{version}

%description -n melt
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

The functionality of the system is provided via an assortment of
tools, XML authoring components, and an plug-in based API.

%package -n %{libname}%{sover}-modules
Summary:        Modules for the MLT multimedia framework
Group:          Productivity/Multimedia/Video/Editors and Convertors
Recommends:     frei0r-plugins
Provides:       mlt(%{sover})(avformat)

%description -n %{libname}%{sover}-modules
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

The functionality of the system is provided via an assortment of
tools, XML authoring components, and an plug-in based API.

%if %{with Qt6}
# Creating a distinct Qt 6 module avoids pulling Qt 6 when installing the
# libmlt modules package
%package -n %{libname}%{sover}-module-qt6
Summary:        Qt 6 module for the MLT multimedia framework
Group:          Productivity/Multimedia/Video/Editors and Convertors
Requires:       %{libname}%{sover}-modules

%description -n %{libname}%{sover}-module-qt6
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

The functionality of the system is provided via an assortment of
tools, XML authoring components, and an plug-in based API.

This package provides a Qt 6 module for MLT.
%endif

%package -n %{libname}%{sover}-data
Summary:        Architecture-independent data files for the MLT multimedia framework
Group:          Productivity/Multimedia/Video/Editors and Convertors
BuildArch:      noarch

%description -n %{libname}%{sover}-data
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.

%package -n python3-%{_name}
Summary:        Python bindings for the MLT multimedia framework
Group:          Development/Languages/Python
BuildRequires:  swig
BuildRequires:  pkgconfig(python3)
Provides:       python3-%{_name} = %{version}
Conflicts:      python3-%{_name} < %{version}

%description -n python3-%{_name}
MLT is a multimedia framework for television broadcasting. It
provides a toolkit for broadcasters, video editors, media players,
transcoders and web streamers.
This package contains python bindings.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%if %{with Qt6} && 0%{?sle_version}
export CC=gcc-13 CXX=g++-13
%endif

# WARNING: building opencv module causes multicore issues - boo#1068792
%cmake \
%if 0%{?suse_version} > 1500
   -DMOD_OPENCV=ON \
%else
   -DMOD_OPENCV=OFF \
%endif
   -DGPL=ON \
   -DGPL3=ON \
   -DSWIG_PYTHON=ON \
   -DCMAKE_SKIP_RPATH=1 \
   -DMOD_GLAXNIMATE=ON \
   -DMOD_GLAXNIMATE_QT6=ON \
%if %{with Qt6}
   -DMOD_QT6=ON
%endif

%cmake_build

%install
%cmake_install

# Get the modules that need data
for MODULE in %{buildroot}%{_libdir}/mlt-%{sover}/libmlt*.so; do
  echo $MODULE
  MODULEDIR=%{_datadir}/mlt-%{sover}/$(echo $MODULE | sed 's|%{buildroot}%{_libdir}/mlt-%{sover}/libmlt\(.*\).so|\1|')
  if [[ "$MODULEDIR" =~ "qt6" ]]; then
    echo "Ignoring $MODULEDIR"
    continue
  fi
  echo $MODULEDIR
  if [ -e %{buildroot}$MODULEDIR ]; then
    echo Done $MODULEDIR
    echo $MODULEDIR >> module_data.dirs
  fi
done

#Link man melt to man melt-7
pushd  %{buildroot}%{_mandir}/man1/
ln -s  melt-%{sover}.1 melt.1
popd

# remove dupes
%fdupes %{buildroot}%{_datadir}/mlt-%{sover}

%ldconfig_scriptlets -n %{lib_pkgname}
%ldconfig_scriptlets -n %{libpp_pkgname}

%files -n %{lib_pkgname}
%{_libdir}/lib%{_name}-%{sover}.so.%{sover}
%{_libdir}/lib%{_name}-%{sover}.so.%{lversion}

%files devel
%{_includedir}/%{_name}-%{sover}
%{_libdir}/cmake/Mlt%{sover}
%{_libdir}/lib%{_name}-%{sover}.so
%{_libdir}/lib%{_name_pp}-%{sover_pp}.so
%{_libdir}/pkgconfig/%{_name}-framework-%{sover}.pc
%{_libdir}/pkgconfig/%{_name_pp}-%{sover_pp}.pc

%files -n %{libpp_pkgname}
%{_libdir}/lib%{_name_pp}-%{sover_pp}.so.%{sover_pp}
%{_libdir}/lib%{_name_pp}-%{sover_pp}.so.%{lversion_pp}

%files -n melt
%{_bindir}/melt
%{_bindir}/melt-%{sover}
%{_mandir}/man1/melt.1%{?ext_man}
%{_mandir}/man1/melt-%{sover}.1%{?ext_man}

%files -n %{libname}%{sover}-modules -f module_data.dirs
%doc AUTHORS NEWS README.md
%license GPLv3 COPYING GPL
%{_libdir}/%{_name}-%{sover}
%dir %{_datadir}/%{_name}-%{sover}/
%{_datadir}/%{_name}-%{sover}/chain_normalizers.ini
%exclude %{_libdir}/%{_name}-%{sover}/libmltglaxnimate-qt6.so
%exclude %{_libdir}/%{_name}-%{sover}/libmltqt6.so

%if %{with Qt6}
%files -n %{libname}%{sover}-module-qt6
%dir %{_datadir}/%{_name}-%{sover}
%{_datadir}/%{_name}-%{sover}/glaxnimate-qt6/
%{_datadir}/%{_name}-%{sover}/qt6/
%dir %{_libdir}/%{_name}-%{sover}
%{_libdir}/%{_name}-%{sover}/libmltglaxnimate-qt6.so
%{_libdir}/%{_name}-%{sover}/libmltqt6.so
%endif

%files -n %{libname}%{sover}-data
%dir %{_datadir}/%{_name}-%{sover}/
%{_datadir}/%{_name}-%{sover}/metaschema.yaml
%{_datadir}/%{_name}-%{sover}/profiles/
%{_datadir}/%{_name}-%{sover}/presets/
%{_datadir}/%{_name}-%{sover}/vid.stab/

%files -n python3-%{_name}
%{python3_sitearch}/_%{_name}%{sover}.so
%{python3_sitearch}/%{_name}%{sover}.py

%changelog
* Wed Aug 28 2024 Christophe Marin <christophe@krop.fr>
- Update to 7.26
  Framework:
  * Fixed a double-free crash in Mlt::Service::profile().
  Modules:
  * Fixes and improvements to the avformat producer:
    Changed to prefer r_frame_rate over avg_frame_rate.
    Fixed lowres if set too high.
    Fixed audio_index=all.
    Fixed variable_frame_rate incorrectly set true on 59.94 fps
    in Matroska.
    Improved performance with intra-only video and reducing the
    frame rate.
    Fixed mono audio handling regression on FFmpeg 7.
    Fixed audio samples may be dropped unexpectly esp. with
    uncompressed.
  * Fixed movit transitions with a non-movit filter on one of its
    inputs.
  * Fixed duration in the glaxnimate producer off by one frame.
  * Added dropshadow filter to the qt module.
  * Fixed resetting animation in kdenlivetitle producer.
  * Added support for LV2 and VST2 plugins in the jackrack module.
  * Fixed crash using av.declick audio filter on FFmpeg 7.
  * Added subtitle filter and producer and subtitle_feed filter to
    the plus module.
  * Added subtitle encoding to the avformat consumer (new properties
    beginning with “subtitle.”).
  * Fixed alang in the the avformat consumer.
  * Added #gps_power keyword to the gpstext filter.
  * Fixed tab handling in the kdenlivetitle producer.
  Other:
  * Added 8- and 10-bit encode presets for SVT-AV1.
  * Fixed building on OpenBSD.
  * Fixed building on musl libc.
  * Fixed consumer properties not updating the automatic profile on
    the melt command line.
  * Added -loglevel command line option to melt.
* Mon Jun 24 2024 Christophe Marin <christophe@krop.fr>
- Update to 7.24:
  Framework:
  * Fixed a small memory leak in mlt_repository.
  * Fixed a small memory leak in MltPushConsumer C++ class.
  * Block connecting a null producer to a service.
  * Include locale.h on any GNU libc platform.
  Modules:
  * Added a new spatialaudio module with filters:
    + ambisonic-decoder
    + ambisonic-encoder
  * Fixed building with FFmpeg 7.
  * Added "meta.media.aspect_ratio" property to the avformat producer.
  * Fixed distort property not working in movit.rect filter.
  * Fixed frames dropping or repeating in the multi consumer.
  * Fixed the dynamic_loudness filter maximizing audio gain.
  * Fixed distortion in the mono filter.
  * Also check for WAYLAND_DISPLAY to detect a graphical session in the qt
  and glaxnimate modules.
  * Fixed the wave filter distorts if wave = 1 with preview scaling.
  * Added the read-only meta.media.%%u.codec.layout property to avformat producer.
  * Set the channel_layout property on the frame for the noise and tone
    audio producers.
  * Fixed outline maximum for the text and dynamictext filters.
  Other:
  * Fixed crash when using -chain from melt.
  * Fixed a small memory leak on Windows fopen().
- Update the gcc version for Leap to match the ones used by Qt6
  packages
- Explicitly install fontconfig and libavfilter build dependencies
* Sat Dec  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 7.22.0:
  Framework:
  * Added new functions:
    + mlt_property_is_color()
    + mlt_property_is_numeric()
    + mlt_property_is_rect()
  * Many new keyframe types:
    + mlt_keyframe_smooth_loose - ~= (same as old mlt_keyframe_smooth - Unity Catmull-Rom spline)
    + mlt_keyframe_smooth_natural - $= (Centripetal Catmull-Rom spline with natural slope)
    + mlt_keyframe_smooth_tight - -= (Centripetal Catmull-Rom spline with 0 slope)
    + mlt_keyframe_sinusoidal_in - a=
    + mlt_keyframe_sinusoidal_out - b=
    + mlt_keyframe_sinusoidal_in_out - c=
    + mlt_keyframe_quadratic_in - d=
    + mlt_keyframe_quadratic_out - e=
    + mlt_keyframe_quadratic_in_out - f=
    + mlt_keyframe_cubic_in - g=
    + mlt_keyframe_cubic_out - h=
    + mlt_keyframe_cubic_in_out - i=
    + mlt_keyframe_quartic_in - j=
    + mlt_keyframe_quartic_out - k=
    + mlt_keyframe_quartic_in_out - l=
    + mlt_keyframe_quintic_in - m=
    + mlt_keyframe_quintic_out - n=
    + mlt_keyframe_quintic_in_out - o=
    + mlt_keyframe_exponential_in - p=
    + mlt_keyframe_exponential_out - q=
    + mlt_keyframe_exponential_in_out - r=
    + mlt_keyframe_circular_in - s=
    + mlt_keyframe_circular_out - t=
    + mlt_keyframe_circular_in_out - u=
    + mlt_keyframe_back_in - v=
    + mlt_keyframe_back_out - w=
    + mlt_keyframe_back_in_out - x=
    + mlt_keyframe_elastic_in - y=
    + mlt_keyframe_elastic_out - z=
    + mlt_keyframe_elastic_in_out - A=
    + mlt_keyframe_bounce_in - B=
    + mlt_keyframe_bounce_out - C=
    + mlt_keyframe_bounce_in_out - D=
  * Fixed missing support for mlt_service_transition in Mlt::Producer() C++ constructor.
  Modules:
  * Fixed rotoscoping filter crash on image with height = 0.
  * Fixed crashed due to qtblend transition requesting an image of 0 width or height.
  * Added support for RtAudio 6 in the rtaudio consumer.
  * Fixed createdate keyword deletes preceeding text in dynamictext filter.
  * Added opacity property to filters that use qtext:
    + dynamictext
    + gpstext
    + qtext
    + timer
  * Added fade_video, fade_audio, and fade_color properties to autofade filter.
  * Added backwards compatibility for changed filter names in frei0r v2.3.1:
    + frei0r.measure_pr0be
    + frei0r.measure_pr0file
    + frei0r.tehroxx0r
    + frei0r.alpha0ps_alpha0ps
    + frei0r.alpha0ps_alphagrad
    + frei0r.alpha0ps_alphaspot
    + frei0r.denoise_hqdn3d
  * Fixed a memory leak in avformat producer with consumer deinterlacer=yadif.
  * Fixed qimage producer color if consumer color_range=pc pix_fmt=yuv444p.
  Other:
  * Fixed ten_bit/ProRes 422 avformat preset produced ProRes 444.
  * Fixed YouTube avformat preset did not output high profile with some hardware encoders.
- Remove 0001-fix-930-support-RtAudio-6.patch
* Fri Oct 13 2023 Dave Plater <davejplater@gmail.com>
- Reenable rtaudio fixed with: 0001-fix-930-support-RtAudio-6.patch
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Add missing QtNetwork BuildRequires
* Mon Oct  2 2023 Dave Plater <davejplater@gmail.com>
- Update to 7.20.0
- libmltglaxnimate-qt6.so no longer builds due to lack of build
  information concerning libQt6Network6
- Upstream changes:
  * Framework:
  Fixed "blank" in a playlist does not have audio normalization filters.
  Fixed serializing mlt_color transparent black as "#00000000" when the
  property was set using an integer or mlt_color.
  Fixed mlt_chain_set_source() would always fetch a frame from the
  producer even if it has "meta.media.frame_rate_num" and
  "meta.media.frame_rate_den" properties making things slow.
  Fixed Mlt::Chain leaking memory.
  * Modules
  Added a blank producer to the core module.
  Added keywords to gpstext filter:
    [#]gps_cadence#
    [#]gps_grade_degrees#
    [#]gps_grade_percentage#
    [#]gps_temperature#
  Added some color_styles to the gpsgraphic filter:
    10 = color by speed (max 100 km/h)
    11 = color by grade (max 90 degrees)
    12 = color by grade (max 20 degrees)
  Added more unit formats to legend_unit property of gpsgraphic filter:
    mmin or m/min
    ftmin or ft/min
  Added keywords to dynamictext filter:
    [#]basename#
    [#]filename#
  Fixed installing filter_audioseam.yml.
  Added an avlink link to the avformat module for FFmpeg filters that
  can benefit from future frames such as adeclick.
  Added the preserve_alpha property to the box_blur filter.
  Fixed loading service metadata for the qt6 and glaxnimate-qt6 modules.
  Fixed a crash when changing the rotate property in avformat producer
  with interlace video.
  Add astream and vstream properties to avformat producer. Unlike
  audio_index and video_index are absolute indices across the entire
  array of streams regardless their type, these new 0-based properties
  are relative to the type audio or video. For example, astream=1 is the
  second audio stream.
  Fixed a possible crash in the avformat producer's mlt_producer_probe
  virtual function.
  Updated the glaxnimate module to version 0.5.4.
  Fixed the sdl2 consumer crashing with the Linux radeonsi_dri driver
  and showing only all black with the Linux nvidia driver.
  * Other
  Fix compiling on Android (not supported by the core developers).
  Changed the avformat consumer FLAC preset to use the flac format.
  Fixed the melt Shift+H and Shift+L keyboard shortcuts when the SDL2
  window has focus.
* Mon Oct  2 2023 Dave Plater <davejplater@gmail.com>
- Disabled rtaudio due to build fail against new rtaudio abi
  see https://github.com/mltframework/mlt/issues/930
* Sun Oct  1 2023 Dave Plater <davejplater@gmail.com>
- Update to 7.18.0
- Upstream changes:
  * Framework:
  Added mlt_audio_free_data().
  Added meta.playlist.clip_position and meta.playlist.clip_length
  properties to mlt_playlist.
  Fixed mlt_frame_get_audio fails on mlt_audio_none.
  * Modules:
  Added two audio filters to core module used on a playlist/track:
    audioseam
    autofade
  Fixed a crash in vidstab filter on image format change.
  Fixed font weight in qtext filter on Qt 6.
  Fixed yuv420p not working in rescale filter.
  Fixed text shadow outline in kdenlivetitle producer.
  Fixed crash when changing the profile with count producer.
  Fixed constructor corruption in frei0r module.
  Fixed deinterlace link was added to invalid producer in xml
  producer.
  Fixed producers not indicating progressive scan video:
    kdenlivetitle
    pango
    qimage
    qtext
  Fixed video scan mode detection in avformat producers that only
  indicate on their container format and not on frames such as Ut
  Video in Matroska.
  Fixed very large images in qimage producer on Qt 6.
  Fixed seeking on clips that use speed_map in timeremap link.
  Fixed a color level problem with sRGB inputs in the movit module.
  Fixed avformat producer's deallocation function for AVCodecContext.
  Fixed field order of qtblend and frei0r.cairoblend transitions.
  Changed the avformat producer seek_threshold default to 64.
* Sun Jun 11 2023 Christophe Marin <christophe@krop.fr>
- Update to 7.16.0
  Framework:
  * Added a chain_normalizers.ini to the data directory.
  * Added New C functions to support deinterlacer links
  * Added support for loading a filter as a link via
    mlt_link_filter_init().
  * Added enum mlt_deinterlacer
  * Added new 10-bit YUV members to enum mlt_image_format
  * Fixed a deadlock and improved quality of start of playback
    when mlt_consumer property prefill is greater than 1.
  * Fixed a couple of data races in mlt_events and mlt_consumer.
  * Fixed a crash in mlt_frame_clone() with movit and the
    mask_start filter.
  Modules:
  * Fixed regressions in version 7.14.0:
    memory and thread count usage in swresample and resample links
    automatic profile support in melt
    crash in count producer
  * Upgraded the glaxnimate git submodule to version 0.5.3.
  * Added avformat/avdeinterlace (default) and xine/deinterlace
    links.
  * Fixed deinterlacing in the multi and qglsl consumers.
  * Added 10-bit video support to movit.convert filter.
  * Several things in the avformat producer:
    Fixed artifacts decoding raw FLAC audio.
    Fixed a potential crash on mlt_producer_probe().
    Fixed seeking on music with album art.
    Fixed possible infinite loop on end-of-file.
    Fixed a potential deadlock.
    Fixed chroma bleeding on interlaced yuv420p.
    Fixed color_range or force_full_range sometimes not working.
    Fixed autorotate property not working with a chain.
    Added audio caching.
    Deprecated the mute_on_pause property.
  * Fixed FFmpeg version 6 compilation error.
  * Fixed rendering the text outline in kdenlivetitle producer.
  * Fixed 'movit.rect property animation.
  * Fixed corrupt video in crop filter when mlt_image_yuv420p requested.
  * Fixed possible null pointer crashes in some audio filters:
    audiolevel
    volume
    loudness
  * Fixed a possible roi assert crash in opencv.tracker filter.
  * Added support for "Nano" algo to the opencv.tracker filter.
  * Added the property fix_background_alpha to the luma transition.
  Other:
  * Added -query links to melt command line.
  * Added avformat consumer presets for 10-bit video
  * Added a clang-format target to CMake and reformatted all code.
  * Added warnings as errors with some exceptions to CMake with Debug
    build type and gcc.
  * Fixed numerous warnings throughout the code.
- Drop patch, no longer needed:
  * 0001-Fix-compilation-with-Werror-return-type.patch
* Sat Mar 18 2023 Christophe Marin <christophe@krop.fr>
- Add a _constraints file to fix oom issues when building mlt
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 7.14.0
  Framework:
  * Added functions to get detailed info about a producer more
    directly
  * Added functions to add normalizer links to chains
  * Changed locale_t to mlt_locale_t to avoid redefinition on
    some systems (e.g. clang/llvm on win32).
  * Fixed the value provided with event "consumer-thread-join"
    to be mlt_event_data_thread as documented.
  * Fixed mlt_image_format_planes() for mlt_image_yuv420p.
  Modules
  * Added a swresample link to the avformat module.
  * Added a resample link to the resample module.
  * Fixed compatibility of avformat module with FFmpeg version 6.
  * Fixed rotoscoping filter when request image size different
    than profile.
  * Fixed timeremap link breaking crop filter.
  * Fixed audio/video sync in avformat producer when the video
    start time is not 0.
  * Improved seeking on a WMA audio file in avformat producer.
  * Optimization to set AVDISCARD_ALL on disinterested streams
    in avformat producer.
  * Added separate demuxing thread in avformat producer.
  * Added filtergraph property to the avformat producer.
  * Fixed filter movit.convert's CPU image converter in
    mlt_tractor and mlt_frame_clone().
  * Fixed using movit module with mlt_chain.
  * Fixed 10-bit full range YUV color input with Movit.
  * Fixed aspect ratio issues in qtblend filter transform.
  * Fixed the movit.luma transition.
  * Changed the qglsl consumer to use an OpenGL core profile
    version 3.2 context to make it compatible with recent
    Movit versions.
  * Upgraded glaxnimate git submodule to version 0.5.2.
  * Fixed xml producer incorrectly adds a path prefix to
    a consumer producer.
  * Fixed using opencv.tracker filter with mlt_chain.
  * Added interlace-aware chroma conversion from
    mlt_image_yuv422 to yuv420p in the avformat consumer.
  * Added the speed_map property to the timeremap link.
  * Fixed the loader producer not injecting the consumer producer
    when a xml producer changes the frame rate.
  * Fixed 'loader' producer corrupts the profile colorspace and
    description when it injects a consumer producer.
  * Added a loader-nogl producer to the core module based on
    loader but prevents adding movit-based filters.
  * Changed count producer to take an optional string argument
    with the name of a loader producer.
  * Fixed yadif deinterlace not working in a mlt_chain.
  * Fixed the bob, weave, greedy, onefield deinterlace filter
    methods on x86-64 architecture.
  Other:
  * Fixed SWIG python shadow functions for mlt7.
  * Added CMake build option MOD_GLAXNIMATE_QT6.
- Add compilation fix:
  * 0001-Fix-compilation-with-Werror-return-type.patch
* Tue Dec 20 2022 Christophe Marin <christophe@krop.fr>
- Build the glaxnimate module. Kdenlive complains if the plugin
  is missing (boo#1206127)
- Change the source URL to get the glaxnimate sources
* Sun Nov 27 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.12.0
  * Fix a couple of major new bugs in the popular qtblend and
    frei0r.cairoblend transitions
  * New color animation APIs with sensible interpolation
  Framework:
  * Added new color animation APIs
  Modules:
  * Updated the following services to support animation of color
    properties: frei0r, chroma, chroma_hold, audiolevelgraph,
    audiospectrum, audiowaveform, gpsgraphic, gpstext, qtcrop,
    qtext
  * Added discontinuity_reset property to dynamic_loudness filter
  * Fixed qtblend transition not blending with an opaque rgba
    image
  * Added support for the "finer" engine in Rubberband version 3
  * Fixed crash in frei0r.cairoblend when threads property not set
  Other:
  * Fixed leaking the xml producer in melt when the XML contains
    a consumer element but no profile information
  * Fixed symbol not found error in rtaudio consumer
* Wed Nov  2 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.10.0
  Framework:
  * Fixed some unguarded null pointers.
  * Added `MLT_REPOSITORY_DENY` environment variable to skip
    loading a module (colon delimited list of file names without
    extension, for example libmltqt).
  * Fixed frame corruption with one frame transition
  * Changed so-called test-card frame with audio to show a
    checkerboard:
  - Added `mlt_image_fill_checkerboard()`
  - Added `mlt_image_fill_white()`
  * Preserve the producer `creation_time` property when creating
    a chain.
  * Added `mlt_image_rgba_opaque()`.
  * Fixed getting a property as a timecode or clock value with 24
    or 23.98 fps in `mlt_property.c`.
  Modules:
  * Added support for Qt 6:
  - Added `MOD_QT6` and `BUILD_TESTS_WITH_QT6` CMake options.
  - Allow installing building and installing both Qt 5 & 6
    modules.
  - Avoid loading both Qt 5 & 6 modules by preferring Qt 5
    (use MLT_REPOSITORY_DENY=libmltqt to block Qt 5 and use
    Qt 6).
  - This is limited to the `qt` module for now and not `glaxnimate`
    (still a work-in-progress).
  * Added support for WebP animation to `qimage` producer.
  * Added `gps_graphic` filter to the `qt` module.
  * Added the `format` property in each producer's get_frame method
    to indicate the producer's default/preferred mlt_image_format
    to facilitate an optimization in the `qtblend` transition when
    the B frame is opaque and has the same aspect ratio.
  * Added property animation to all audio visualization filters in
    the `qt` module.
  * Improved TGA format detection in `qimage` filter.
  * Fixed `qtblend` transition has incorrect scaling with consumer
    scaling.
  * Fixed an case of incorrect alpha scaling in `qtblend` transition.
  * Fixed `luma` transition not updated when `resource` property
    changes.
  * Added the `alpha_operation` property to the `shape` filter.
  * Updated the `glaxnimate` git submodule to version 0.5.1.
  * Fixed `lines` filter in `oldfilm` regression in v7.6.0.
  * Added `dbpeak` property to the `audiolevel` filter in dB.
  * Fixed memory leak using some frei0r plugins in conjunction with
    an `affine` that animates the `rect` property.
  Other:
  * Fixed building for musl.
  * Fixed underlinking iconv in `gdk` module on MinGW.
  * Fixed SWIG CMake options can overwrite each other.
  * Fixed SWIG 4 no longer generates a `mlt.php`
- Drop patches, merged upstream:
  * 0001-Another-take-on-fixing-the-wcrtomb-issue.patch
  * 0001-Split-to-allow-installing-Qt5-and-Qt6-in-parallel-80.patch
  * 0002-Remove-deprecated-C-register-keyword-815.patch
  * 0003-Move-CMake-code-for-testing-to-the-right-position-fo.patch
  * 0004-Add-MLT_REPOSITORY_DENY-envvar-to-skip-plugin-loadin.patch
  * 0005-Avoid-to-load-both-qt-modules-816.patch
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream changes to build a Qt 6 based mod:
  * 0001-Split-to-allow-installing-Qt5-and-Qt6-in-parallel-80.patch
  * 0002-Remove-deprecated-C-register-keyword-815.patch
  * 0003-Move-CMake-code-for-testing-to-the-right-position-fo.patch
  * 0004-Add-MLT_REPOSITORY_DENY-envvar-to-skip-plugin-loadin.patch
  * 0005-Avoid-to-load-both-qt-modules-816.patch
* Thu Jun 23 2022 Hans-Peter Jansen <hpj@urpla.net>
- Update to 7.8.0
  + Framework
  * Added mlt_frame_get_alpha_size() and refactored code to use
    it.
  * Fixed a possible null pointer crash in
    mlt_service_apply_filters().
  + Modules
  * Added a glaxnimate producer to the glaxnimate module.
  * Added new file extensions for glaxnimate producer: json,
    lottie, rawr, tgs.
  * Removed Qt4 compatibility from the qt module.
  * Added Qt6 compatibility to the qt module.
  * Added new file extensions for qimage producer: avif, heic,
    heif, jxl.
  * Fixed color_range when using the multi consumer.
  * Fixed reloading updated results in the loudness filter.
  * Fixed image_mode=blend in the timeremap link.
  * Fixed crash regression in swscale filter with odd size YUV
    image.
  * Fixed the choppy filter may result in black frames with
    transitions.
  * Prevent a crash in avfilter producer for a bug in glibc with
    _FORTIFY_SOURCE=3.
- Remove merged upstream fixes
  * 0001-fix-798-missing-function-returns.patch
  * 0001-Supply-a-proper-return-value-on-non-void-functions.patch
- Add
  * 0001-Another-take-on-fixing-the-wcrtomb-issue.patch
* Fri May 27 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.6.0
  + Framework:
  * Added `Mlt::Animation::next_key()` and `previous_key()` with
    error checking.
  * Fixed the `moduledir` and `mltdatadir` variables in the
    pkg-config file.
  * Removed calling `setlocale()` in `mlt_factory_init()` (moved
    to `melt` option `-setlocale`).
  * Added `mlt_properties_copy()` and `Mlt::Properties::copy()`.
  * Changed some primarily internal property names to consolidate
    on "consumer."
    as a prefix convention for all consumer properties copied to
    `mlt_frame`s.
  * Added consumer property `deinterlacer` to replace deprecated
    `deinterlace_method`.
  * Fixed full range color from producer to consumer.
  * Added `mlt_slices_size_slice()` helper function.
  * Fixed choppy playback due to large values in `frame_rate_num`
    or `frame_rate_den` in `mlt_consumer`.
  * Added performance optimization for a single slice in
    `mlt_slices`.
  + Modules:
  * Added `audiolevelgraph` video filter to the `qt` module.
  * Added property `segment_gap` to the `audiospectrum` video
    filter.
  * Added `segments` property to the `audiolevelgraph` and
    `audiospectrum` filters.
  * Fixed loading image sequence with extended UTF-8 characters
    in the name of a folder for the `qimage` producer.
  * Fixed a crash in `avformat` producer if the `rotate` property
    is set after the first frame is fetched.
  * Added the `invert_mask` property to the `shape` video filter.
  * Changed `avformat` producer to normalize frame rates very
    close to non-integer broadcast frames 24/1.001, 30/1.001,
    and 60/1.001.
  * Converted the `chroma` and `chroma_hold` filters' `key`
    property to a proper color type.
  * Added slice threading to:
  - `avformat` producer (with FFmpeg v5)
  - `swsscale` (with FFmpeg v5)
  - `lift_gamma_gain`
  - `shape`
  - `charcoal`
  - `vignette`
  - `wave`
  - `threshold`
  - `tcolor`
  - `sepia`
  - `mirror`
  - `invert`
  - `grain`
  - `lines`
  - `spot_remover`
  * Improved the speed of the `oldfilm` filter.
  * Added a faster `box_blur` filter to the core module and
    deprecated the `boxblur` filter in the kdenlive module.
  * Fixed preview scaling for the `avfilter.gblur` filter.
  * Fixed incorrect text overlap in `kdenlivetitle` producer.
  * Improved audio synchronization in `avformat` when playing
    in reverse.
  * Added much more service metadata (documentation).
  * Fixed full range 10-bit video input in `avformat` producer.
  * Fixed full range color handling in:
  - `avformat` producer
  - `avcolor_space`
  - `brightness`
  - `resize`
  - `luma` transition
  - `movit.convert`
  - `charcoal`
  - `invert`
  - `shape`
  * Fixed identifying unsupported colorspaces in `avformat`
    producer.
  * Fixed preserving the alpha channel in the `avfilter.fspp`
    filter.
  + Other
  * Some CMake fixes.
- Add upstream fixes:
  * 0001-fix-798-missing-function-returns.patch
  * 0001-Supply-a-proper-return-value-on-non-void-functions.patch
* Mon Feb  7 2022 Antonio Larrosa <alarrosa@suse.com>
- Installed files included a rpath to a build directory. Do not
  use rpath at all.
* Mon Dec 20 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.4.0
  Framework:
  * Added more constructors and assignment operators in C++
    wrapper:
    + Mlt::Filter::Filter(Mlt::Filter*)
    + Mlt::Link::Link(Mlt::Link*)
    + Mlt::Link::Link(Mlt::Service&)
    + Mlt::Link::Link(Mlt::Link&)
    + Mlt::Link::Link(Mlt::Link const&)
    + Mlt::Link::operator=(Mlt::Link const&)
    + Mlt::Service::Service(Mlt::Service*)
  * Fixed serialized animation in
    mlt_animation_serialize_cut_tf() and
    mlt_animation_serialize_cut() to include a trailing keyframe
    value.
  Modules:
  * Added property animation for avfilter filters.
  * This only works for numeric parameters, but many libavfilter
    options that have a type string are actually numeric in
    nature but accept a string expression.
  * Added rotate property to avformat producer to override
    orientation.
  * Changed jackrack module to silence false LADSPA plugin
    loading errors.
  * Fixed a crash in the oldfilm filter when using preview
    scaling.
  * Fixed timeremap link distorts audio when speed is zero.
  * Added nautical mile and knot units of measure to the gpstext
    filter.
  * Fixed full range color handling with embedded tractor (e.g.
    same track transition).
  * Fixed device capture in avformat producer regression in
    version 7.2.0.
  * Fixed a crash in the matte transition.
* Mon Nov  1 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.2.0
  Framework:
  * Added support for `mlt_properties` as a child of
    `mlt_properties` including XML (de)serialization:
    + `mlt_property_set_properties()`
    + `mlt_property_get_properties()`
    + `mlt_properties_set_properties()`
    + `mlt_properties_get_properties()`
    + `mlt_properties_get_properties_at)(`
    + `Mlt::Properties::set()`
    + `Mlt::Properties::get_props()`
    + `Mlt::Properties::get_props_at()`
    Applications can use this to store structured data in its
    own namespace, for example "shotcut:markers". And modules
    could use this for hierarchical parameters.
  * Fixed crash in `mlt_transition` upon inserting or removing a
    track.
  * Stopped loading `mlt_profile` until needed in `mlt_chain`
    creation.
  Modules:
  * Added filter `gpstext` that is similar to `dynamictext`
    based on data in a GPX file.
  * Added speed parameter to `timer` filter.
  * Added WebP presets for `avformat` consumer.
  * Added a pixelate option to the `opencv_tracker` filter's
    `blur` property.
  * Fixed `center_bias` of `crop` filter not working with
    `use_profile`.
  * Fixed some missing RGB `mlt_image_format` renames after
    change in v7.0.0. This primarily affected presets and
    service metadata.
  * Fixed a crash when changing preview scaling in `timeremap`
    link.
  * Fixes problems due to adding redundant normalize filters
    upon loading a producer from XML.
  * Ensure filters added by the `loader` producer always come
    first in list.
  * Fixed a crash using `shape` and `affine` filters together on
    `color` producer.
  * Fixed a crash when a `vidstab` file fails to open.
  * Changed `vidstab` filter to save its file in ASCII text mode.
  * Fixed a clang LTO error in the `decklink` module.
  * Fixed a video decoding regression on some videos in the
    `avformat` producer.
  * Fixed a crash in the `audiowaveform` filter.
  * Fixed loading a relative filename from XML for `mask_start`
    with `shape`.
  * Fixed "#filedate#" in `dynamictext` filter when used with
    `timeremap` link.
  * Fixed `timer` filter's new `speed` property interaction with
    `start` delay.
  * Fixed a crash with YUYV422 (YUY2) input in `avformat`
    producer.
  * Fixed data race condition in `timeremap` link.
  * Fixed compiling `avformat` module with FFmpeg git beyond
    v4.4 with many deprecations removed.
  * Fixed alpha channel size calculation in `brightness` filter.
  * Restore legacy tracker and the new DaSiam tracker for OpenCV
    >= 4.5.3 in the `opencv_tracker` filter.
  * Fixed a crash in `opencv_tracker` on `shape_width` = 0.
  * Fixed incorrect handling of in and out points and duration
    in the `opencv_tracker` filter.
  * Fixed the `composite` transition leaking left border of an
    image on the right side on uneven width.
  * Fixed a problem handling some UTF-8 in thhe `typerwriter`
    filter.
  Other:
  * Added support for the `RELOCATABLE` CMake option for Linux
    or BSD build.
* Mon Sep  6 2021 Dave Plater <davejplater@gmail.com>
- Remove unnecessary BuildRequires:  pkgconfig(OpenEXR)
* Mon Aug 30 2021 Dave Plater <davejplater@gmail.com>
- Enabled opencv to fix boo#1184430 by enabling motion tracking
* Sat Jun 12 2021 Dave Plater <davejplater@gmail.com>
- Really removed alternatives from melt sub package.boo#1187238
* Tue May 18 2021 Dave Plater <davejplater@gmail.com>
- Removed alternatives from melt sub package
* Sun May 16 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.1
  * Fixed a system-installed build cannot finds its modules and
    data.
  * Fixed the python installation path for binaries.
  * Added support for the `DESTDIR` environment variable when
    creating melt symlink.
  * Increased the build constant for the maximum size of a line
    of a properties file.
  * Fixed the vid.stab metadata install path.
- Drop mlt-7.0.0-python_install_dir.patch (merged upstream)
* Mon May  3 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 7.0.0
  Framework:
  * Added `mlt_chain` and `Mlt::Chain` classes.
  * Added `mlt_link` and `Mlt::Link` classes.
  * Added a `link` value to service `type` in the service
    metadata schema.
  * Added a boolean `animation` parameter attribute to the
    service metadata schema.
  * Added `mlt_animation_shift_frame()` and
    `Mlt::Animation::shift_frames()`.
  * Added `mlt_animation_get_string()`.
  * Fixed using a stale cached property animation string.
  * Added `mlt_image` and `Mlt::Image` classes.
  * Remove legacy "height + 1" workaround in image allocation.
  * Fixed a crash on setting `timewarp` speed higher than 23x.
  * Added `mlt_audio_silence()`.
  * Removed `mlt_image_opengl`.
  * Replaced variadic arguments in `mlt_events` with new
    `mlt_event_data` APIs.
  * Removed `mlt_geometry` APIs.
  * Renamed `mlt_image_rgb24a` as `mlt_image_rgba`.
  * Renamed `mlt_image_rgb24` to `mlt_image_rgb`.
  * Renamed `mlt_image_glsl` to `mlt_image_movit`.
  * Renamed `mlt_image_glsl_texture` to
    `mlt_image_opengl_texture`.
  * Removed virtual function `mlt_frame::get_alpha_mask()`.
  * Removed `mlt_frame_get_alpha_mask()`.
  * Removed deprecated functions:
    + `mlt_sample_calculator`
    + `mlt_sample_calculator_to_now`
    + `mlt_channel_layout_name`
    + `mlt_channel_layout_id`
    + `mlt_channel_layout_channels`
    + `mlt_channel_layout_default`
    + `mlt_slices_init`
    + `mlt_slices_close`
    + `mlt_slices_run`
    + `mlt_playlist_move_region`
    + `Mlt::Playlist::move_region`
  * Fixed a rounding error calculating display aspect ratio in
    `mlt_profile_from_producer()`.
  Modules:
  * Added a `timeremap` link to the core module with animatable
    `map` property. (Speed can increase or decrease between
    keyframes including reverse.)
  * Added `chain` and `link` XML elements to `xml` module.
  * Added "meta.media.has_b_frames" property to `avformat`
    producer.
  * Removed deprecated modules:
    + `dv`
    + `gtk2` (not gdk)
    + `kino`
    + `linsys`
    + `lumas`
    + `motion_est`
    + `swfdec`
    + `videostab`
  * Removed the following services:
    + `data_feed` filter
    + `data_show` filter
    + `region` filter and transition
    + `sdl_image`
  * Converted filters to use new `mlt_image` class:
    + `brightness`
    + `imageconver`
    + `mirror`
    + `spot_remover`
  * Deprecated the `audiowave` filter.
  * Added the ability to build the `jackrack` module without
    JACK to get only LADSPA producers and filters.
  * Deprecated `start` and `end` properties for the following
    filters:
    + `brightness`
    + `panner`
    + `boxblur`
    + `wave`
    + `volume`
  * Removed deprecated `font` property from `pango` producer.
  * Improved album art (attached pic) detection in `avformat`
    producer.
  * Improved the `resample` filter to have less artifacts and
    use less memory.
  Other:
  * CMake: nearly complete rewrite.
  * Removed the old configure bash scripts and Makefiles.
  * Added `-chain` and `-link` options to `melt` command line.
- Switch build to cmake
- Drop libmlt-fixluma.patch (no longer useful)
- Add mlt-7.0.0-python_install_dir.patch
- Create single devel subpackage as cmake scripts are
  undifferentiated
- Rename melt subpackage and add update-alternatives
- Spec cleanup
* Tue Apr 13 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.26.1
  * This version fixes a major regression in version 6.26.0 in
    the avformat producer to read from network URLs.
* Sun Apr 11 2021 Dave Plater <davejplater@gmail.com>
- Removed depreciated webvfx linked package, qmelt is no longer
  needed for shotcut export.
- Deleted obsolete webvfx-nobrowser.patch and
  webvfx-versioned-libdir.patch
* Sat Apr 10 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.26.0
  Modules:
  * Added support for `hwaccel` query string parameter to the
    `avformat` producer. It accepts the following values: vaapi
    and cuda.
  * Added support for `hwaccel_device` query string parameter to
    the `avformat` producer. This is only used with vaapi
    (device path) and cuda.
  * Improved the usage of image slice threading in `frei0r`.
    This only applies when `threads`=0 and only works with some
    frei0r plugins that you must decide yourself.
  * Added an ellipse item to `kdenlivetitle` producer.
  * Added support for PNG and GIF as album art in the `avformat`
    producer.
  * Added BT.2020 color space metadata to the `avformat`
    producer.
  * Resolved many FFmpeg deprecations in the `avformat` producer
    making it possible to support AV1 decoding.
  * Added a `strobe` fitler that periodically makes the alpha
    channel transparent.
  * Added a new `typewriter` text filter (currently only works
    with the kdenlivetitle producer).
  * Improved sound quality for lower pitch shifts in `rbpitch`.
  * Fixed speed of trick play in the `jack`, `rtaudio`,
    `sdl_audio`, and `sdl2_audio` consumers.
  * Fixed matrix for independent channels in `swresample` filter.
  * Fixed leading zeros for the `timer` filter.
  * Fixed flickering using `affine` with a `luma` transition.
  * Fixed a crash using RGBA images in the `qimage` producer
    (regression in v6.22.0).
  * Fixed `brightness` filter misbehaves on `alpha` > 1.
  * Fixed writing `flac` format file does not set its duration
    in the `avformat` consumer.
  * Fixed an infinite loop in `rbpitch` filter.
  * Fixed `ttl` in the `qimage` producer.
  * Fixed building with OpenCV 4.5
  * Fixed artifacts with multiple HTML `qtext` filters and frame
    threading.
  * Deprecated the `start` and `end` properties on the following
    (use property animation instead):
    + brightness
    + panner
    + boxblur
    + wave
    + volume
  * Deprecated the following services:
    + data_show
    + region
    + transition filter
    + autotrack_rectangle
    + motion_est
    + slowmotion
  Other:
  * CMake
    + Fixed building without SWIG.
    + Added many "MOD_..." options to explictly disable modules.
    + Added src/tests and the option `BUILD_TESTING`, which
    defaults off.
    + All dependency checks moved to top level CMakeLists.txt.
    + Install melt man page.
    + Install oldfilm SVG files.
    + Added src/examples.
    + Install framework/metaschema.yaml.
    + Fixed `plusgpl` datadir.
    + Added all swwig/ languages.
    + Increased C++ standard to C++14.
  * Added an `AV1` encoding preset.
  * Improved documentation of the requirement for C11.
  * The minimum version of FFmpeg is v4.0 and Libav is no longer
    supported.
- Drop libmlt-0.8.2-vdpau.patch and everything related to vdpau
  (no longer present in the tree)
- Enable libebur128
* Mon Dec  7 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.24.0
  Framework:
  * Trigger a `property-changed` event on
    `mlt_properties_pass_list`.
  * Fixed using a video transition with a video clip on an audio
    track.
  * Reduce the amount of service caching to 2X #tracks to reduce
    memory usage.
  Modules:
  * Added the `pillar_echo` filter to the plus module.
  * Added a `qtcrop` filter to the qt module.
  * Added `html`, `resource`, `overflow-y`, and `_hide`
    properties to the `qtext` filter for rich text.
  * Added the filter `choppy` to the core module.
  * Added slice threading to the `brightness` filter.
  * Fixed compiling with OpenCV 4.
  * Fixed the colors when using `mlt_image_format=rgb24a` with
    `avformat` consumer.
  * Fixed a possible crash in the `timewarp` producer on sources
    with non-integer frame rates.
  * Fixed a regression in version 6.22 with multiple affine
    filters at the same time.
  * Fixed possible abort or deadlock on recursive pthread
    mutexes in `avformat` producer.
  * Fixed a crash in `crop` filter with large `center_bias`
    value when `use_profile` is 1.
  * Fixed a white video frame appearing on threaded rendering in
    `freeze` filter.
  * Fixed MLT XML DRD to permit empty playlists, which may occur
    on empty tracks in a multitrack.
  * Fixed initializing QApplication in the `qimage` producer.
  * Fixed interpolation when scaling with the `affine` rect and
    geomety properties.
  * Fixed high memory usage with high factors of pitch shifting
    in the `rbpitch` filter.
  * Fixed a crash on files with more than 32 streams in the
    `avformat` producer.
  Other:
  * Added the Python binding to the CMake build.
  * Added the `sdl` (v1) module to the CMake build.
  * Removed minrate and maxrate from the `webm` avformat
    consumer preset.
* Sun Aug  2 2020 aloisio@gmx.com
- Update to version 6.22.1
  * This patch version only fixes the version reported in the
    CMake build.
* Fri Jul 31 2020 aloisio@gmx.com
- Update to version 6.22.0
  Framework:
  * Added mlt_properties_exists() and
    Mlt::Properties::property_exists().
  * Added mlt_audio C class
  * Added Mlt::Audio C++ class
  * Fixed drop-frame timecode for 59.94 fps.
  * Fixed crash on null pointer passed to mlt_consumer_stop().
  Modules:
  * Fixed frei0r transitions with preview scaling.
  * Fixed affine ox and oy properties incorrect with preview
    scaling.
  * Fixed a crash and incorrect preview scaling with more than
    one affine
    filter active on the same frame.
  * Fixed preview scaling for the rotoscoping filter.
  * Added the sample_fmt property to the avformat consumer.
  * Fixed a possible segfault in the mix transition.
  * Removed support for text keyframes to the text and qtext
    filters
    to fix regression on strings containing '='.
  * Disable frame-threading with bigsh0t, distort0r, and medians
    frei0r plugins.
  * Added "meta.media.%%d.stream.projection" property the
    avformat producer.
  * Fixed a crash with with filters not supporting preview scale
    in frei0r transitions.
  * Fix artifacts in luma transition and affine filter with
    frame-threading.
  * Stop including 'title="Anonymous Submission"' in xml
    consumer.
  * Fixed a crash in opencv.tracker filter.
  * Fixed a crash in composite transition if luma file fails to
    load.
  * Added validations in opengl module to prevent asserts in
    Movit.
  * Fixed building with OpenCV 4.
  * Moved some services from gtk2 module to new gdk module:
    gtkrescale filter, pango producer and pixbuf producer
  * Deprecated the gtk2 module and no longer enabled by default.
  * Changed avformat producer to accept a '?' in
    argument/resource property by escaping it as '\?'.
  * Changed the background property of the affine filter to be
    mutable.
  * Deprecated the linsys (DVEO SDI) module.
  * Fixed changing the audio_index property in the avformat
    producer.
  * Changed resample filter to more resiliant to frequency
    changes.
  * Added a video_delay property to the sdl2_audio and rtaudio
    consumers.
  * Add millisecond options to the timer filter.
  * Fixed the in point handling for the timewarp producer.
  * Fixed some audio gaps and sync issues with the rbpitch
    filter and timewarp pitch compensation.
  * Fixed a possible crash caused by producer consumer.
  * Changed avformat consumer to set AVOption color_primaries
    based on the MLT colorspace if not already set as property.
  * Fixed crop right on image with odd width skews image in crop
    filter.
  * Fixed incorrect silence value for unsigned 8-bit audio in
    avformat producer.
  * Changed qimage to use Qt's internal orientation detection
    instead of libexif.
  * Reduced clicks in mix transition by silencing buffers on
    discontinuity.
  * Improved A/V synchronization in (sw)resample filters - also
    reduces audio clicks.
  * Improved speed of the qimage producer.
  * Fixed incorrect color using libx264rgb in avformat consumer.
  * Fixed relative paths for avfilters that have the "filename"
    option.
  * Fixed some avfilters dropping the alpha channel: smartblur,
    vaguedenoiser.
  * Improved performance of the resize filter.
  * Fixed an affine filter inside a transition was always
    nearest neighbor interpolation.
  * Changed the lift_gamma_gain filter to use round values up.
  Other:
  * Fixed melt option "-group" applies to an implicit consumer.
  * Added "-quiet" option to melt (implies -silent but more so).
  * CMake build improvments adding modules: gdk, jackrack, lumas
    resample, sox and vorbis
  * Added avformat consumer presets: Slide-Deck-H264 and
    Slide-Deck-HEVC
  * Removed intra=1 from some avformat presets (use g=1 for
    intra only): intermediate/MPEG-2, intermediate/MPEG-4
    and lossless/H.264
- Drop 0001-Fix-build-with-Qt-5.15.0.patch (merged upstream)
* Thu Apr  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.0.patch
* Mon Feb 17 2020 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.20.0
  Framework
  * Added consumer scaling:
    + mlt_profile_scale_width()
    + mlt_profile_scale_height()
    + Mlt::Profile::scale_width()
    + Mlt::Profile::scale_height()
    + support for a double "scale" property to melt and the xml
    producer
  * Fixed mlt_properties_set() with an invalid expression.
  * Added new functions that do not evaluate expressions:
    + mlt_properties_set_string()
    + Mlt::Properties::set_string()
  * Improved the service-caching heuristic in mlt_multitrack.
  * Fixed possible crashes in mlt_playlist get_frame() and
    mlt_filter_process().
  Modules
  * Added the rubberband module with a rbpitch filter.
  * Added pitch compensation to timewarp producer.
  * Added the invert_scale property to the affine filter and
    transition.
  * Added the reverse property to shape filter.
  * Added support for text keyframes to the text and qtext
    filters.
  * Added support for the CSRT and MOSSE algorithms in
    opencv.tracker filter.
  * Fixed a crash on empty algo property in the opencv.tracker
    filter.
  * Changed vorbis module to no longer be deprecated.
  * Improved colorspace conversions in the avformat module.
  * Fixed audio artifacts on initial seek to in point in
    avformat producer.
  * Fixed the colorspace of the cached image in avformat
    producer.
  * Fixed white video flashes on property changes in the qtext
    filter.
  * Fixed a crash in the rotoscoping filter with large spline
    deviations.
  * Fixed a crash in the sdi consumer if the driver is not
    loaded.
  * Improved support for a video clip as luma producer to the
    luma transition.
  * Fixed a crash in the matte transition.
  * Fixed a crash when using invert property =1 in the composite
    transition.
  Other
  * Added more avformat consumer presets:
    + intermediate/DNxHR-HQ
    + intermediate/ProRes HQ
    + ALAC
    + FLAC
  * Fixed some parameters in the XDCAM and D10 avformat
    presets.
  * Fixed link failure on some CPU architectures.
- Refreshed libmlt-fixluma.patch
* Tue Nov 12 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.18.0
  Framework:
  * Fixed some data races in mlt_consumer, mlt_deque, and
    mlt_property.
  * Fixed the mlt_events listener incorrect owner argument.
  * Added support for the LC_ALL environmant variable on Windows.
  * Fixed the argument to mlt_factory_init() not working on
    Windows.
  * Fixed mlt_service_identify() not reliable in some use cases.
  * Added some default and copy constructors and assignment
    operators to mlt++
    + Filter()
    + Filter( const Filter &filter )
    + Filter& operator=( const Filter &filter )
    + Producer( const Producer &producer )
    + Producer& operator=( const Producer &producer )
    + Properties( const Properties &properties )
    + Properties& operator=( const Properties &properties )
    + Service( const Service &service )
    + Service& operator=( const Service &service )
    + Transition()
    + Transition( const Transition &transition )
    + Transition& operator=( const Transition &transition )
  * Added mlt_luma_map:
    + mlt_luma_map_init
    + mlt_luma_map_new
    + mlt_luma_map_render
    + mlt_luma_map_from_pgm
    + mlt_luma_map_from_yuv422
  * Fixed preset overrides depend on the XML attribute order.
  * Fixed serializing an animated property with a new length.
  Modules:
  * Fixed interpolation in rotoscoping filter.
  * Fixed crop filter not working with color producer.
  * Fixed some data races in the sdl and sdl2 consumers.
  * Fixed some data races in the avformat producer.
  * Added a movit.flip filter to the opengl module.
  * Fixed using filters on frei0r producers.
  * Added support for in and out attributes on the "consumer"
    xml element.
  * Fixed using an in point with the multi consumer.
  * Fixed avfilter fails if the image size changes.
  * Fixed showing superfluous decimals for seconds in the timer
    filter.
  * Stop serializing an invalid producer as an "INVALID" text
    producer in xml.
  * Fixed an access violation crash in wave filter.
  * Added the meta.media.color_range property to the avformat
    producer.
  * Fixed full range yuv422p not converted correctly in the
    avformat producer.
  * Fixed the text filter not working with pango.
  * Fixed a regression using dynamictext with pango.
  * Added a position property to avfilter for filters that need
    position info.
  * Fixed avfilter.subtitles not using the source position.
  * Added an analyze property to vidstab filter. When set,
    analysis only starts and the results file written if true.
  * Fixed crash combining affine the affine filter with the
    shape filter.
  * Added interlace detection from AVCodecContext.field_order.
  * Changed the avformat producer to not use the rescale.interp
    frame property.
    Previously, when interp == nearest, it would relax seeking.
    Now, seek accuracy is reduced during trick play (rewind or
    fast forward).
  * Fixed sws flags for auto-inserted scalers in avfilter.
  * Fixed a double free crash in ladspa filter on channel count
    mismatch.
  * Refactored the composite and luma transitions to use
    mlt_luma_map.
  * Refactored the pgm producer and shape filter to use
    mlt_luma_map.
  * Refactored the lumas module to use mlt_luma_map.
  * The lumas module is now disabled by default and must be
    explicitly enabled.
  * Added property animation to the threshold filter.
  * Added a cairoblend_mode filter to the frei0r module to
    affect a frei0r.cairoblend transition used to
    composite/blend tracks.
  * Added support for new vaapi options to the avformat consumer:
    + connection_type: x11 or drm
    + driver
    + kernel_driver
  * Fixed the timewarp producer with a colon in the filename.
  * Fixed a relative file name with a colon in it in the xml
    producer.
  * Fixed defaulting to album or poster art if there is another
    video stream.
  * Fixed parameter animation in frei0r plugins when using frame
    threads.
    This change also enables frame-threading for more plugins.
  * Improved the qtblend filter to not process alpha if no
    transparency.
  * Added a background_color property to the qtblend filter.
  * Fixed the opencv.tracker incorrect behavior on cut clips.
  * Changed opencv.tracker to store absolute frame numbers.
  * Fixed incorrect frame offset on render in opencv.tracker.
  * Add an alpha_over property to luma transition. This
    addresses a behavior regression in version 6.14.0.
  * Fixed noimagecache not working in the avformat producer.
  Other:
  * Mlt++ now requires C11 compiler support.
  * Fixed closing melt SDL2 window from window manager (i.e.
    close button).
  * Added -repository option to the melt command.
  * Added unit tests for Mlt::Event.
  * Fixed returning image data for Python 3.
  * Switch to python3 by default.
  * Updated the prores encoding presets to set vendor ID and
    colr atom.
  * Added a CMake build system. This is not yet prefered over
    the existing configure script and Makefiles and has less
    flexibility. It is a start and has limited support.
- Use python 3
- Added libmlt-fixluma.patch
* Wed May  8 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.16.0
  Framework:
  * Added functions to get/set a creation date to a producer
    + mlt_producer_get_creation_time()
    + mlt_producer_set_creation_time()
    + Mlt::Producer::set_creation_time()
    + Mlt::Producer::get_creation_time()
  Modules:
  * Fixed dance filter not showing when lower track is
    transparent.
  * Refactored dynamictext filter to use
    mlt_producer_get_creation_time().
  * Marked frei0r rgsplit0r plugin version < 1.1 as not
    thread-safe.
  * Fixed possible null pointer crash in
    mlt_properties_serialise_yaml.
* Sun Mar 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 6.14.0
  * This version is mostly fixes plus a few API additions and
    filters.
  Framework:
  * Added mlt_profile_lumas_dir().
  * Added mlt_frame_get_unique_properties().
  * Added mlt_playlist_reorder() and Mlt::Playlist::reorder().
  * Added some new convenience constructors to mlt++
    + Producer(mlt_profile profile, const char *id, const char
  * service = NULL)
    + Consumer(mlt_profile profile, const char *id , const char
  * service = NULL)
    + Transition(mlt_profile profile, const char *id, const char
  * arg = NULL)
    + Filter(mlt_profile profile, const char *id, const char
  * service = NULL)
    + Tractor(mlt_profile profile, char *id, char *arg = NULL)
  * Added Mlt::Transition::connect(Service&).
  * Added unit tests for mlt_playlist.
  * Fixed a crash on invalid transition track values in
    mlt_transition.
  * Fixed a deadlock regression in v6.12.0 of mlt_consumer when
    starting from
    a paused state (producer speed=0).
  Modules:
  * The avformat module now requires at least FFmpeg v2.4 or
    Libav 12.
  * Added mask_start and mask_apply filters to the core module.
  * Added qtext filter to qt module.
  * Changed dynamictext and timer filters to use qtext.
  * Fixed number of digits for seconds in timer filter.
  * Added mlt_image_format property to color producer.
  * Improved color accuracy of libswscale RGB->YUV conversion.
  * Fixed frei0r producer not working with tractor.
  * Fixed decklink consumer stalling on dropped frames.
  * Generate lumas for 16:9, 9:16 (vertical), and square aspect
    ratios.
  * Fixed crash in qimage when alpha_size is zero.
  * Fixed the mlt_consumer channels property not being passed to
    multi consumer.
  * Fixed the shape filter for full range color and crashes.
  * Converted the shape filter to use mlt_animation.
  * Added a use_mix property to the shape filter.
  * Fixed invert=1 and mix=100 gives wrong image in shape filter.
  * Fixed a possible free null pointer in the linsys sdi
    consumer.
  * Fixed using destroyed temporary object in qimage.
  * Fixed a possible null pointer dereference in the
    spot_remover filter.
  * Fixed memory leak on swr_convert() failure in swresample
    filter.
  * Fixed possible null pointer dereference in affine when not
    using rect.
  * Fixed loading image sequence on Windows in qimage.
  * Fixed some null pointer crashes using Movit opengl services.
  * Fixed sdl2 consumer crashes during initialization on Linux
    or BSD.
  * Fixed distorted image using melt_file.
  * Fixed qimage build on Qt version < 5.5.
  * Added offset property to the timer filter.
  * Changed the boxblur hori & vert properties' minimum to 0.
  * Fixed crash in duplicate frame on rotated videos.
  * Added automatic scaling and padding to avfilter.
  * Fixed field order when encoding progressive as interlace.
  * Fixed frei0r plugins to use the number of slices from the
    threads property.
  * Fixed over compositing with transparent clips in luma
    transition.
  * Added sliced processing to dissolve-with-alpha using the
    threads property.
  * Added createdate keyword to dynamictext filter.
  * Fixed possible crash changing audio_index in avformat
    producer.
  * Fixed small memory leaks in xml consumer, jackrack, and
    timewarp producer.
  * Fixed compiling opencv module with OpenCV > 3.
  Other:
  * Added vertical video profiles:
    + vertical_hd_30
    + vertical_hd_60
  * Mlt++ now requires C++11 compiler support.
  * Added --disable-windeploy to configure to keep bin & lib
    folders on Windows.
  * Added support for consumer in & out to melt.
  * Fixed color accuracy of lossless/Ut Video preset and use
    pix_fmt yuv422p.
  * Fixed x264 lossless preset to use crf=0.
  * Fixed compiling with mingw32.
  * Fixed build with Python 3.
* Mon Nov 26 2018 aloisio@gmx.com
- Update to version 6.12.0
  Framework:
  * Changed buffer property to be mutable and adaptive to speed
    property in mlt_consumer.
  * Changed macOS RELOCATABLE build to use standard app bundle
    layout:
    + lib/mlt      -> ../PlugIns/mlt
    + lib/frei0r-1 -> ../PlugIns/frei0r-1
    + lib/ladspa   -> ../PlugIns/ladspa
    + share/mlt    -> ../Resources/mlt
    + share/movit  -> ../Resources/movit
  * Fixed a_track of transitions matching deleted track in
    mlt_tractor_remove_track().
  * Fixed multi-thread race crash in mlt_properties_clear().
  * Fixed possiblle null pointer crash in
    mlt_property_get_rect() and mlt_property_get_time().
  * Fixed non-animated strings containing ';' or '=' in
    mlt_animation_parse().
  * Fixed crash in clear_property() with mlt_animation.
  Modules:
  * Added a generic text filter to the plus module.
  * Added a timer filter to the plus module.
  * Added audio timeout handling to sdl2 consumers.
  * Added spot_remove filter to the plus module.
  * Added dds, ico, and webp filename extensions for qimage
    producer.
  * Added support for color_range property in avformat consumer:
    "pc" or "jpeg" for full range, otherwise limited range.
  * Added a window property to the audiowaveform filter.
  * Added MM:SS.SS to the timer filter.
  * Added query string param "multi" to the xml producer to
    force using the
    multi consumer.
  * Improved WebP image support in avformat producer.
  * Integrated hwupload filter in avformat consumer if using
    VAAPI codec.
  * Changed count producer to use pango if qtext not available.
  * Changed qt moduled to not call XInitThreads()
  * Changed color producer to only set alpha on frame if rgb24a
    requested or not opaque.
  * Changed the xml producer to pass quality and performance
    parameters to the multi consumer.
  * Fixed sdl2_audio distortion (regression in v6.10.0).
  * Fixed dynamictext filter to not error on empty text.
  * Fixed dynamictext aliased (regression in v6.10.0).
  * Fixed qimage outputs premultiplied if scaled internally.
  * Fixed crash in cbrts consumer if running property was never
    set.
  * Fixed rendering edges of some typefaces in qtext producer.
  * Fixed qimage fails to load with wrong filename extension.
  * Fixed affine dark right and bottom edge artifacts regression
    in (v6.10.0).
  * Fixed support for vp8 and vp9 with alpha channel in avformat
    producer.
  * Fixed interpolation mode selection in qimage producer.
  * Fixed crash in qimage with alpha channel.
  * Fixed some AAC MP4 files start playing from middle in
    avformat producer.
  * Fixed crash in avfilter if initialization fails.
  * Fixed crash in mix when frame rate is very low.
  * Fixed crash on missing luma file in composite transition.
  * Fixed A/V sync on some files in avformat producer.
  * Fixed seeking on audio filter with album art in avformat
    producer.
  * Fixed colorspace conversion in avformat consumer.
  Other:
  * Added more avformat consumer presets:
    + alpha/Quicktime Animation
    + alpha/vp8
    + alpha/vp9
    + alpha/Ut Video
    + lossless/Ut Video
  * Added square video profiles:
    + square_1080p_30
    + square_1080p_60
  * Added support for nodejs to the swig bindings.
  * Changed configure script to require opencv module be
    explicitly enabled.
  * Numerous spelling fixes in source code and comments thanks
    to codespell.
* Sun Oct 21 2018 davejplater@gmail.com
- Disabled build of opencv module to fix boo#1068792.
- Only build sdl2 module.
* Mon Jul  2 2018 aloisio@gmx.com
- Update to version 6.10.0
  * This version fixes bugs and supports serializing animation
    keyframes with a specified time format (previously only
    frame number).
  Framework:
  * Reverted mlt_pool change in v6.8.0 pending further testing.
    (USE_MLT_POOL compiler define is now a 0/1 boolean, defaults
    to 1.)
  * Fixed crash regression in v6.8.0 "parsing non-animated
    string as an animation."
  * Added pointer checks to mlt_animation.
  * Changed producer cache size heuristic in mlt_multitrack to
    be more liberal.
  * Fixed handling reserved characters in names for YAML in
    mlt_properties.
  * Added clamping to prevent computing negative in and out
    points to mlt_producer.
  * Added functions to serialize animation with a time format:
    + mlt_animation_serialize_cut_tf()
    + mlt_animation_serialize_tf()
    + mlt_property_get_string_tf()
    + mlt_property_get_string_l_tf()
    + mlt_properties_get_value_tf()
    + Mlt::Properties::get(int, mlt_time_format)
    + Mlt::Animation::serialize_cut(mlt_time_format, int, int)
  * Added functions to clear a property to mlt_properties:
    + mlt_property_clear()
    + mlt_properties_clear()
    + Mlt::Properties::clear()
  Modules:
  * Fixed enabling sliced pix_fmt conversion in avformat
    producer.
  * Fixed incorrect seek and sync on audio files with discard
    packets.
  * Added support for avcodec_send_frame() API to avformat
    consumer.
  * Fixed compile errors with Libav master.
  * Fixed a crash in affine transition.
  * Fixed a crash in ladspa filters when consumer frame rate is
    low (e.g. <= 8).
  * Fixed a crash in boxblur filter.
  * Added animation support to boxblur hori and vert properties.
  * Fixed a crash in movit.convert.
  * Fixed incorrect alpha in affine transition blending routine.
  * Converted frei0r from deprecated mlt_geometry to
    mlt_animation API.
  * Fixed tilde in text string for pango producer.
  * Fixed using more than one channelcopy filter.
  * Fixed the mono filter reducing volume level.
  * Fixed degraded audio scrubbing in sdl2_audio consumer.
  * Converted dynamictext filter to use affine transition for
    more correct
    alpha compositing and sub-pixel positioning.
  * Added time format support for animation keyframes to the xml
    consumer.
  * Added animation support to more affine transition properties:
    + fix_rotate_x
    + fix_rotate_y
    + fix_rotate_z
    + fix_shear_x
    + fix_shear_y
    + fix_shear_z
    + ox
    + oy
    + scale_x
    + scale_y
  * Fixed gaps in text when characters overlap in qtext and
    kdenlive producers.
  * Fixed a crash in pixbuf producer with multiple render
    threads.
  * Converted the oldfilm vignette filter from mlt_geometry to
    mlt_animation.
  Other:
  * Numerous updates to mlt-xml.dtd.
  * Categorized many of the encode presets (using
    meta.preset.name).
* Wed Jun 20 2018 aloisio@gmx.com
- Update to version 6.8.0
  * This version improves support for multi-channel audio and
    adds some new manipulation functions to the mlt_animation
    API.
  Framework:
  * Added support for musl C library.
  * Added functions for audio channel layouts:
    + mlt_channel_layout_name()
    + mlt_channel_layout_id()
    + mlt_channel_layout_channels()
    + mlt_channel_layout_default()
  * Added channel_layout property to mlt_consumer.
  * Added mlt_channel_layout enum.
  * Disabled memory pooling by default and require compile macro
    USE_MLT_POOL to re-enable it.
  * Fixed reliability of keyframed properties serializing
    properly.
  * Fixed parsing non-animated string as an animation.
  * Added more functions to mlt_animation:
    + mlt_animation_key_set_type()
    + mlt_animation_key_set_frame()
    + Mlt::Animation::key_set_type()
    + Mlt::Animation::key_set_frame()
  Modules:
  * Fixed some crashes in qimage producer especially with alpha
    channel.
  * Fixed >2 channel audio output in the SDL consumers.
  * Fixed >2 channel audio output in the rtaudio consumer on
    Windows.
  * Fixed vorbis encoding with FFmpeg v3.4+.
  * qimage and qtext are now higher priority than gtk2 pixbuf
    and pango by the loader producer.
  * Added support for more channel counts to decklink consumer.
  * Added swresample filter based on libswresample from FFmpeg.
    This is now the preferred channel count normalizing filter
    used by the loader producer.
  * Fixed the strange "Undefined constant" and "Unable to parse
    option value" log messages in the the avformat consumer.
  * Fixed GIF and DPX writing in avformat consumer.
  * Reduced the memory usage of the affine transition and
    filters.
  * Fixed a crash in kdenlivetitle producer.
  * Fixed a crash in the rotoscoping filter.
  * Fixed frame rate reported in Matroska and WebM files
    produced by the avformat consumer.
  * Added sdl2_audio consumer.
  * Fixed alpha channel support for more pixel formats in the
    avformat producer.
  * Converted the affine transition to use mlt_rect and
    mlt_animation.
  * Fixed LADSPA plugins with mono channel audio.
  Other:
  * Fixed a melt command line parsing bug when argument supplied
    to -transition.
  * Fixed melt with SDL2 on Windows not using stdio and stderr.
  * Improved speed of the vp9 avformat consumer preset.
* Mon Jun 18 2018 bjorn.lie@gmail.com
- Enable pkgconfig(vidstab) BuildRequires unconditionally, now
  available in openSUSE.
- Build with ffmpeg unconditionally, ffmpeg is available in
  openSUSE.
* Sun May  6 2018 davejplater@gmail.com
- Update to 6.6.0+git20180502 to enable shotcut 18.05 to build.
- Upstream changes:
  * Fix affine and region filters alter the frame's position.
  * Fix mono channel configuration for ladspa plugins. (#334)
  * Convert affine to mlt_rect and animation APIs.
  * Add mlt_animation_key_set_frame() and Animation::key_set_frame().
  * Fix build for Libav
  * Fix crash on composite transition with unexpected pgm luma
  https://bugs.kde.org/show_bug.cgi?id=381110
  * Fix alpha support for more pixel formats Kdenlive issue #391963
  * Add mlt_animation_key_set_type() and Animation::key_set_type().
  * Fix rotoscoping crash
  * Fix parsing non-animation string as animation.
  * Fix mlt_animations not reliably serializing.
  * Fix crash with kdenlivetile caused by wrong malloc size
  * Add filter_swresample. (#305)
  * Fix #284 GIF encoding not working.
  * Fix segmentation fault when using qimage png producer #296
* Sun Apr  1 2018 avvissu@yandex.by
- Build with sdl and sdl2:
  * Preserve backward compatibility. Both "sdl" and "sdl2" modules
  can be compiled into MLT 6.6.0 and later
* Mon Mar  5 2018 davejplater@gmail.com
- Build with SDL2.
* Wed Jan 24 2018 davejplater@gmail.com
- Update to release 6.6.0 and build with gcc7
- Combined melt6 sub package into melt subpackage.
- Remove incorporated patches:
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch, rem_close.patch,
  use-recommended-freetype-include.patch and
  libmlt-nomorexlocale_h.patch.
- Upstream changes:
  This version builds upon the previous release with performance
  improvements using the sliced image processing framework.
  It also improves compatibility with dependencies
  (FFmpeg, Qt 5, SDL 2, NDI, OpenCV, libebur128).
  For full details see:
  /usr/share/doc/packages/libmlt6/NEWS
* Fri Aug 25 2017 davejplater@gmail.com
- Fix build against glibc-2.26 with libmlt-nomorexlocale_h.patch.
- Rebased 6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch,
  libmlt-0.8.2-vdpau.patch, rem_close.patch and
  use-recommended-freetype-include.patch.
* Sat Aug  5 2017 olaf@aepfle.de
- Build with Qt5 unconditional because PackageHub has a recent Qt5
* Thu Jul 13 2017 davejplater@gmail.com
- Build with gcc6, fix build failure for 42.2/3 due to movit
  building with gcc6.
* Thu Jul  6 2017 jengelh@inai.de
- Trim filler wording from descriptions; fix identical
  descriptions being used in different subpackages.
* Wed Jul  5 2017 klaas.freitag@suse.com
- Add rem_close.patch from upstream that prevents crashes of apps
  in some circumstances, as reported on openSUSE ML.
  https://github.com/mltframework/mlt/commit/a3188e301b5a9a1f25dbb98a510e366363348e64
* Fri Jun  9 2017 davejplater@gmail.com
- Added files for linked package webvfx which provides qmelt needed
  by shotcut for video export see boo#1043070. Webvfx has to build
  within the mlt sources.
* Tue Feb 21 2017 mrueckert@suse.de
- replace mlt-6.4.1_fix_opengl_install.patch with
  6c658e5d8cd11933bf799a2a985aa4b24cfbcb60.patch:
  upstream solution to the problem
* Tue Feb 21 2017 mrueckert@suse.de
- enable OpenGL and OpenVC modules
  new BR:
  - OpenGL: movit-devel
  - OpenVC: pkgconfig(openvc)
- added mlt-6.4.1_fix_opengl_install.patch: fix install of OpenGL
  filter files.
* Wed Nov 16 2016 aloisio@gmx.com
- Update to version 6.4.1
  * This is a hot-fix release for v6.4 that fixes a symbol
    version declaration problem for the new C++ method
    Mlt::Profile::is_valid().
* Sat Nov 12 2016 aloisio@gmx.com
- Update to version 6.4.0
  This is both a bugfix and enhancement release:
  Framework
  * Added functions for multi-threaded slice-based image processing:
    mlt_slices_init, mlt_slices_close, and mlt_slices_run.
  * Added Mlt::Profile::is_valid().
  * Added MLT_DIRLIST_DELIMITER to mlt_types.h.
  * Renamed mlt++/config.h to mlt++/MltConfig.h.
  * Fixed mlt_properties_set_lcnumeric() on macOS.
  * Fixed address of Free Software Foundation in comment headers.
  Modules
  * Added crop_to_fill property to composite transition.
  * Added sliced_composite property to composite transition.
  * Added peak and true peak properties to loudness_meter filter.
  * Added qtblend transition and filter to qt module.
  * Added ndi (NewTek NDI) module with producer and consumer.
  * Added opencv module with opencv_tracker filter.
  * Added line_spacing, strech, wrap_width, and wrap_type properties to
    pango producer.
  * Added oblique value for style property to pango producer.
  * Added fontmap-reload event to pango producer.
  * Added support for pkg-config to sdl module.
  * Added .kra (Krita Image) file name extension to loader.dict.
  * Improved performance of kdenlivetitle producer.
  * Improved decklink producer and consumer.
  * Improved accuracy of seeking on lossy compressed audio in
    avformat producer.
  * Improved mix transition using 32-bit floating point.
  * Fixed avfilter when image format changes.
  * Fixed loading relative file name in vidstab filter.
  * Fixed crash on Windows with avfilter.
  * Fixed parsing LADSPA_PATH with semi-colon delimiter on Windows.
  * Fixed parsing FREI0R_PATH with semi-colon delimiter on Windows.
  * Fixed reading relative path with backslash (Windows) in xml producer.
  * Fixed loading relative file name for av.file (avfilter).
  * Fixed loading multiple LADSPA plugins on some systems.
  * Fixed compile error when not configured with --enable-gpl.
  * Fixed loading in avfilter.lut3d in locales with comma decimal point.
  * Fixed a possible crash in resample filter.
  * Fixed alpha channel in kdenlivetitle producer.
  * Fixed possible crash in pixbuf and qimage producers.
  * Fixed count when counting down in count producer.
  Other
  * Moved some avformat presets from lossless to new intermediate folder.
  * Added a YouTube avformat consumer preset.
  * Changed metadata.rb metadata publisher to output Markdown.
- Removed dupes
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 6.2.0:
  + There are no framework changes in this release. The major
    announcement is the introduction of support for libavfilter!
    This is still a work-in-progress. It is limited to FFmpeg 2.3
    and up, and there are a number of filters that are black-listed
    because they are known to not integrate with MLT, which is not
    a full libav* environment or simple wrapper for it. There are
    likey avfilters that are not yet black-listed but might not
    work because they have not been completely tested. Also, they
    do not support MLT's keyframable property animation nor its
    frame-threaded parallelism due to architectural or integration
    limitations. However, some avfilters are slice-threaded
    (internal parallelism), and that works. Finally, libavfilter
    filtergraph syntax is not supported either.
    All of the supported libavfilters are exposed as MLT filters
    beginning with the prefix "avfilter." All of the avfilter
    parameters are exposed as MLT properties with the "av." prefix
    to prevent clashes with MLT properties. You can run `melt
  - query filters` to see the new avfilters, and `melt -query
    filter=avfilter.rotate`, for example, to view generated
    documentation for an individual filter.
  + Notable fixes and enhancements in this release:
  - Added support for libavfilter to avformat module.
  - Added auto-rotate support to avformat producer.
  - Added animated GIF preset for avformat consumer.
  - Prevent serializing and deserializing mlt_type property to
    xml module.
  - Fixed relative paths for WebVfx "plain:" resources in xml
    module.
  - Updated libebur128 to v1.1.0 in plus module.
  - Added dynamic_loudness filter to plus module.
  - Added loudness_meter filter to plus module.
  - Qt 5 fixes for kdenlivetitle producer.
  - Added gradients and text shadows to kdenlivetitle producer.
  - Added support for building rtaudio against external build of
    lib.
  - Upgraded bundled RtAudio to v4.1.2.
  - Added status parameters to ladspa producer and filters.
  - dded 5.1 surround to stereo downmix to audiochannels filter
    in core module.
  - Fixed compiling SWIG bindings for Ruby 2.0.
- Changes from version 6.0.0:
  + This is a bugfix and minor enhancement release. Note that our
    release versioning scheme has changed. We were approaching 1.0
    but decided to synchronize release version with the C library
    ABI version, which is currently at v6. Here are some of the
    notable changes and enhancements:
  + Framework:
  - Added unit tests for tractor, multitrack, and field.
  - Deprecate mlt_frame_get_alpha_mask().
  - Added drop_count readable property to mlt_consumer.
  - Added mlt_factory_repository().
  - Added mlt_properties_to_utf8().
  - Define MIN, MAX, CLAMP in mlt_types.h in not already defined.
  - Switched to APPLE and _WIN32 defines throughout codebase.
  + Modules:
  - Added UDP and SMPTE 2022-2 support to cbrts consumer.
  - Fixed build against latest FFmpeg versions - now requires
    v1.1 and up.
  - Added audiospectrum filter to qt module.
  - Added meta.media.0.codec.rotate property to avformat producer
    to let apps and other services get the media orientation.
  - Make the avformat producer handle animated images.
  - Added style property to dynamictext filter.
  - Added timewarp producer to core module.
  - Fixed slowly accumulating A/V sync drift in mix audio
    transition.
  - Added width_crop and width_fit properties to pango producer.
  + Melt:
  - Added -abort option to simply exit without full cleanup.
  - Fix key-press handling on Windows.
- Add pkgconfig(libpulse) BuildRequires: Build pulseaudio support.
- Add pkgconfig(Qt5OpenGL) BuildRequires: Build qt5 opengl support.
- Add pkgconfig(fftw3) BuildRequires: Build lightshow, fft and
  dance filters.
- Drop libmlt-ffmpeg3.patch: Fixed upstream.
* Thu Feb 18 2016 olaf@aepfle.de
- Remove usage of depcrecated functions
  libmlt-ffmpeg3.patch
* Mon Nov 16 2015 olaf@aepfle.de
- Restore pkgconfig(libavdevice), multiple providers should be
  solved with Prefer: pkg in prjconf
* Fri Nov 13 2015 wbauer@tmo.at
- Build with ffmpeg on Leap and Tumbleweed by default to make it a
  bit more useful (boo#954841)
- Replace pkgconfig(libavdevice) BuildRequires with
  libavdevice-devel to prevent an unresolveable choice between that
  and libavdevice-libav-devel
* Thu Nov  5 2015 wbauer@tmo.at
- Build against Qt5 on Leap as well, the included kdenlive 15.08.1
  (which is KF5/Qt5 based) will crash on startup otherwise (boo#930616)
* Fri Aug  7 2015 fisiu@opensuse.org
- Update to 0.9.8
  + Framework
  * Added mlt_service_disconnect_producer() and
    Mlt::Service::disconnect_producer().
  * Added mlt_multitrack_disconnect() and Mlt::Multitrack::disconnect().
  * Added mlt_tractor_remove_track() and Mlt::Tractor::remove_track().
  * Added mlt_service_insert_producer() and Mlt::Service::insert_producer().
  * Added mlt_multitrack_insert() and Mlt::Multitrack::insert().
  * Added mlt_tractor_insert_track() and Mlt::Tractor::insert_track().
  * Added mlt_transition_set_tracks() and Mlt::Transition::set_tracks().
  * Added Mlt::Properties::get_animation().
  * Added Mlt::Properties::get_anim().
  * Added Mlt:Animation class with methods: length(), is_key(),
    keyframe_type(), get_item(), next_key(), previous_key(), set_length(),
    remove(), interpolate(), serialize_cut().
  * Added mlt_animation_key_count() and Mlt::Animation::key_count().
  * Added mlt_animation_key_get() and Mlt::Animation::key_get().
  + Modules
  * Added audiowaveform video filter.
  * Added fft audio filter.
  * Added dance video filter (uses fft).
  * Added lighshow video filter (uses fft).
  * Added distort property to movit.rect video filter.
  * Added rotate property to pango video producer.
  * Added 2K DCI and 4K modes to decklink producer and consumer.
  * Added audiomap (channel remapping) filter.
  * Added property animation to all LADSPA audio filters and producers.
* Sun Apr 19 2015 tittiatcoke@gmail.com
- libmlt for Tumbleweed/Factory is now QT5 based !!
- Update to 0.9.6
  + Framework
  * Added color_trc (transfer characteristic) property to mlt_consumer and mlt_frame.
  * Added Mlt::Profile::set_display_aspect(int, int).
  * Added mlt_pool_stat().
  * Added mlt_smpte_df and mlt_smpte_ndf to mlt_time_format for non-drop-frame timecode support.
  * Added Mlt::Tractor::Tractor(Mlt::Profile&).
  * Added mlt_frame_get_alpha().
  * Added default, copy, and assignment methods to Mlt::Frame.
  * Added Mlt::Filter::process(Mlt::Frame&).
  + Modules
  * Added support for color_trc property to avformat and opengl modules.
  * Performance improvements for composite and matte transitions.
  * Added fill, halign, and valign properties to affine transition and filter.
  * Added producer.* and consumer.* properties to consumer producer.
  * Fixes for libavformat and libavcodec v56.
  * Dropped support for FFmpeg < v1.0 and Libav < v9.
  * Added a lumakey filter.
  * Added a localtime property to dynamictext filter.
  * Added date/time format string support to dynamictext filter.
  * Added no_root property to xml consumer.
  * Added audio-only tone producer.
  * Added drop property to count producer.
  * Added caching to pango producer to improve performance.
  + Other
  * Added WMV and WMA avformat consumer presets.
  * Added a ProRes-Kostya avformat consumer preset.
  * Changed VP9 WebM preset to use Opus audio codec.
  * Added 4K UHD and 2.5K QHD profiles.
  * Added x265-medium and x265-medium-pass1 avformat consumer presets.
  * Added a unit test for Mlt::Frame.
- Drop upstreamed patches
  * mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch
* Tue Nov 11 2014 dimstar@opensuse.org
- Temporarly disabled vid.stab support, as the submission to
  Tumbleweed hit a legal road bump. While it's enabled in the devel
  project, other packages depending on libmlt are being blocked.
* Tue Nov  4 2014 olaf@aepfle.de
- Enable exif support
- Add missing stdlib.h inclusion in qt
  (mlt-0.9.2-Add-missing-stdlib-include-for-getenv.patch)
* Sat Oct 25 2014 reddwarf@opensuse.org
- Add vid.stab support
  Add BuildRequires: pkgconfig(vidstab)
* Thu Oct 16 2014 nico.kruber@gmail.com
- Update to 0.9.2
  + Framework
  * Added "boolean" parameter type and "argument" parameter
    attribute to service metadata schema.
  * Added mlt_properties_frames_to_time().
  * Added mlt_properties_time_to_frames().
  * Changed mlt_events_fire() to return the number of listeners.
  * Added consumer-thread-create and consumer-thread-join events.
  * Added LC_NUMERIC handling for Windows.
  * Added mlt_playlist_mix_out() and mlt_playlist_mix_in().
  * Added mlt_properties_from_utf8().
  + Modules
  * Renamed "qimage" module to "qt".
  * Added support for Qt 5.
  * Added qtext producer, which is now prefered by dynamictext
    filter over pango.
  * Added xml-nogl consumer.
  * Consolidated dgraft, burningtv, and rotoscoping into new
    plusgpl module.
  * Added vid.stab module with vidstab and deshake filters. This
    depends on external vid.stab library unlike its predecessors.
  * Rewrote opengl module.
  * Added loudness filter based on EBU R128.
  * Added rgblut filter to plus module.
  * Added luma-only liftgammagain filter to plusgpl module.
  * Added lift_gamma_gain filter to plus module.
  * Added support new keyframable animated properties to brightness,
    volume, panner, boxblur, wave, sepia, charcoal, burn, gamma,
    grain, dust, lines, tcolor, oldfilm.
  * Added movit.luma transition to opengl module.
  * Added cbrts consumer to plusgpl module.
  * Removed the "ppm" PPM-pipe producer.
  * Added more VITC functionality to decklink module.
  * Added matte transition to core module.
  + DEPRECATION WARNINGS
  * Deprecate videostab module with videostab and videostab filters.
    This will not be removed soon in order to keep old scripts and
    projects functional.
  * Deprecate the dv (libdv), kino, and vorbis modules. These are
    scheduled to be removed in next release.
- Update use-recommended-freetype-include.patch
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Added use-recommended-freetype-include.patch -- Freetype upstream
  recommends using their macros together with ft2build include.
  Positive sideeffect is that this patch makes it build with both
  freetype2 2.5.1, and older version
* Sun Jun 30 2013 tittiatcoke@gmail.com
- Update to 0.9.0
  * new, properly integrated property animation API
  * Improved pause behavior when using buffered rendering in
    mlt_consumer.
  * Added mlt_color type.
  * Deprecated mlt_geometry API.
  * Support for the latest versions of FFmpeg and Libav (but
    dropping support for 0.5 and 0.6 versions).
  * Added alpha channel output to avformat consumer.
  * Added reconnect and exit_on_disconnect properties to avformat
    producer.
  * Added qglsl consumer to use opengl with avformat, sdi, and
    decklink.
  * Added avsync module with blipflash producer and consumer for
    testing.
  * Added new "count" producer to gtk2 module.
  * Changed frei0r to use index-based property names making it
    impervious to param name changes (param name still accepted
    for compatibility).
  * Added default parameter values to frei0r metadata.
  * Added more python example web services.
  * Started a unit test suite.
- Dropped patch libmlt-0.8.0-versioned_dirs.patch due to upstream
  support for versioning (--enable-extra-versioning configure flag)
* Thu May  2 2013 reddwarf@opensuse.org
- By default disable VDPAU as requested by Dan Dennedy
* Fri Apr 19 2013 tiwai@suse.de
- Fix missing buildrequire for alsa-devel
* Mon Jan 21 2013 reddwarf@opensuse.org
- Update to 0.8.8
  * Purely a bugfix release
* Fri Nov 30 2012 reddwarf@opensuse.org
- Make multiple versions of melt parallel installable
* Tue Nov 27 2012 crrodriguez@opensuse.org
- Fix build in non-x86 platforms (ARM, PPC ETC..)
* Thu Nov 15 2012 reddwarf@opensuse.org
- Update to 0.8.6
  * Fix a performance regression on videos that use full-range
    colorspaces such as yuv420p.
* Wed Nov 14 2012 reddwarf@opensuse.org
- Update to 0.8.4
  * Added playlist-next event and PlaylistNextListener to Ruby binding
  * FFmpeg 1.0 and libAV master compatibility
  * Improvements to motion_est filter to generate keyframes for apps
  * Added audiolevel (measurement) filter
- Remove libmlt-0.8.2-ffmpeg1.patch and libmlt-0.8.0-optflags.patch.
  Have been applied upstream.
* Mon Oct  1 2012 reddwarf@opensuse.org
- Add libmlt-0.8.2-ffmpeg1.patch to fix build with ffmpeg 1.0
* Thu Aug 30 2012 reddwarf@opensuse.org
- Update to 0.8.2
  * Overhaul of A/V sync with libavformat-based inputs.
  * Fix a major memory leak introduced in previous release.
  * Fixes to problems revealed by Coverity Scan static analysis.
  * Improved encoding presets.
  * melt can now be built without SDL with define MELT_NOSDL, which is handy
    for running it as a child process on Windows and OS X.
  * melt can now be signaled to quit, which also makes it more useful as a
    child process.
- Rebase libmlt-0.8.2-vdpau.patch
- Remove libmlt-0.8.0-fix_null_pointer_dereference.patch. Applied upstream.
* Mon Aug 27 2012 toddrme2178@gmail.com
- Added libmlt-0.8.0-fix_null_pointer_dereference.patch, fixed
  upstream.  See and BNC # 777416 and upstream comit
  17a64a9aa20aa27861b6169e38859358a323c5a8
* Sat Aug 25 2012 reddwarf@opensuse.org
- Make python-mlt require at least the same version of libmlt++
* Fri Aug 17 2012 reddwarf@opensuse.org
- Make vdpau support work without the need of the devel package
* Thu Aug 16 2012 reddwarf@opensuse.org
- Package module specific data in the -modules subpackage
* Sun Aug 12 2012 reddwarf@opensuse.org
- Add modules and data directories as variables in the .pc file
* Tue Aug  7 2012 reddwarf@opensuse.org
- Version modules and data directories
- Put the full python module in %%python_sitearch
- Added "mlt(%%{soname})(avformat)" and "python-%%{_name}%%{soname}"
  provides to help openshot select the versions it needs
* Sat Aug  4 2012 reddwarf@opensuse.org
- Compile the python binding with %%{optflags}, getting debug
  information on the way.
- Fix VDPAU support
* Mon Jun 18 2012 reddwarf@opensuse.org
- Update to 0.8.0
  + Addition of time properties
  + ABI incompatible changes to some mlt_property functions
  + Improve seek speed on AVCHD when using FFmpeg v0.9.1+ (NOT
    Libav!)
  + Composite and dissolve speed improvements on x86-64
  + Improve performance of caching in image producers
  + Add device enumeration to decklink producer and consumer
- Remove included copy of GPLv3, upstream added it
- Remove dependency to x11 when unneeded
- Enable VDPAU support in the avformat module
* Tue Mar 27 2012 idonmez@suse.com
- Set license to GPLv3 for discussion in bnc#753622
* Sat Mar 10 2012 idonmez@suse.com
- Drop swfdec dependency, swfdec is not maintained.
* Thu Feb 23 2012 reddwarf@opensuse.org
- Update to 0.7.8
* Sun Jan  2 2011 reddwarf@opensuse.org
- Initial package
